@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 PYINSTALLER
 Module for pyinstaller.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,14 +29,16 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = ['get_hook_dirs']
+
 import os
+from typing import List
 
 
-def get_hook_dirs():
+def get_hook_dirs() -> List[str]:
     """
     Return hook dirs to PyInstaller.
 
     :return: Hook dir list
-    :rtype: list[str]
     """
     return [os.path.dirname(__file__)]
